@@ -8,12 +8,10 @@ checkControl <- function(control, fail = TRUE) {
   return(fail)
 }
 
-check.semtree.control <- function(control, fail = TRUE)
-{
+check.semtree.control <- function(control, fail = TRUE) {
   attr <- attributes(control)$names
   def.attr <- attributes(semtree.control())$names
-  if ((length(intersect(attr, def.attr)) != length(attr)))
-  {
+  if ((length(intersect(attr, def.attr)) != length(attr))) {
     unknown <- setdiff(attr, def.attr)
     msg <-
       paste("Control object contains unknown parameters:", unknown)
@@ -22,9 +20,8 @@ check.semtree.control <- function(control, fail = TRUE)
       stop()
     } else {
       ui_warn(msg)
-      
+
       return(FALSE)
-      
     }
   } else {
     temp <- semtree.control()
@@ -36,23 +33,20 @@ check.semtree.control <- function(control, fail = TRUE)
         }
       }
     } # end for
-    
-    return (TRUE)
+
+    return(TRUE)
   }
-  
-  
-  
-  return (length(intersect(attr, def.attr)) == length(attr))
-  
+
+
+
+  return(length(intersect(attr, def.attr)) == length(attr))
 }
 
-check.semforest.control <- function(control, fail = TRUE)
-{
+check.semforest.control <- function(control, fail = TRUE) {
   attr <- attributes(control)$names
   def.attr <- attributes(semforest.control())$names
-  
-  if ((length(intersect(attr, def.attr)) != length(attr)))
-  {
+
+  if ((length(intersect(attr, def.attr)) != length(attr))) {
     unknown <- setdiff(attr, def.attr)
     msg <-
       paste("Control object contains unknown parameters:", unknown)
@@ -61,12 +55,10 @@ check.semforest.control <- function(control, fail = TRUE)
       stop()
     } else {
       ui_warn(msg)
-      
+
       return(FALSE)
-      
     }
   } else {
-    return (TRUE)
-    
+    return(TRUE)
   }
-}
\ No newline at end of file
+}
